@@ -3,8 +3,8 @@ import logging
 import math
 
 import pandas
-from pytdx.exhq import TdxExHq_API
-from pytdx.hq import TdxHq_API
+from .contrib.pytdx.exhq import TdxExHq_API
+from .contrib.pytdx.hq import TdxHq_API
 from tqdm import tqdm
 
 from mootdx import config
@@ -51,22 +51,21 @@ class StdQuotes(object):
         with self.client.connect(*self.bestip):
             return self.client.get_traffic_stats()
 
-    def quotes(self, symbol=[]):
+    def quotes(self, symbol=None):
         '''
         获取实时日行情数据
 
         :param symbol: 股票代码
         :return: pd.dataFrame or None
         '''
-
-        logger.debug(type(logger))
+        if not symbol:
+            return None
 
         if type(symbol) is str:
             symbol = [symbol]
 
         with self.client.connect(*self.bestip):
             symbol = get_stock_markets(symbol)
-            print(symbol)
             result = self.client.get_security_quotes(symbol)
 
             return to_data(result)
