@@ -4,8 +4,9 @@ import os
 
 from mootdx.consts import TYPE_GROUP
 from mootdx.utils import get_stock_market
-from pytdx.reader import (BlockReader, CustomerBlockReader, TdxDailyBarReader,
-                          TdxExHqDailyBarReader, TdxLCMinBarReader)
+from .contrib.pytdx.reader import (BlockReader, CustomerBlockReader,
+                                   TdxDailyBarReader, TdxExHqDailyBarReader,
+                                   TdxLCMinBarReader)
 
 logger = logging.getLogger(__name__)
 
@@ -131,7 +132,7 @@ class StdReader(ReaderBase):
             vipdoc = os.path.join(self.tdxdir, 'T0002', 'hq_cache',
                                   '{}.dat'.format(symbol))
 
-        format = TYPE_GROUP if group else None
+        fmt = TYPE_GROUP if group else None
 
         if os.path.exists(vipdoc):
             return reader.get_df(vipdoc, format)
