@@ -32,7 +32,7 @@ def get_stock_market(symbol='', string=False):
     """判断股票ID对应的证券市场
     匹配规则
     ['50', '51', '60', '90', '110'] 为 sh
-    ['00', '13', '18', '15', '16', '18', '20', '30', '39', '115'] 为 sz
+    ['00', '12'，'13', '18', '15', '16', '18', '20', '30', '39', '115'] 为 sz
     ['5', '6', '9'] 开头的为 sh， 其余为 sz
     :param string:
     :param symbol:股票ID, 若以 'sz', 'sh' 开头直接返回对应类型，否则使用内置规则判断
@@ -48,8 +48,8 @@ def get_stock_market(symbol='', string=False):
         ('50', '51', '60', '90', '110', '113', '132', '204')):
         market = 'sh'
 
-    elif symbol.startswith(
-        ('00', '13', '18', '15', '16', '18', '20', '30', '39', '115', '1318')):
+    elif symbol.startswith(('00', '12', '13', '18', '15', '16', '18', '20',
+                            '30', '39', '115', '1318')):
         market = 'sz'
 
     elif symbol.startswith(('5', '6', '9', '7')):
